@@ -348,8 +348,8 @@ class fabba_model(Aggregation2D):
     """    
     
     def __init__ (self, tol=0.1, alpha=0.5, 
-                  sorting='norm', scl=1, verbose=1,
-                  max_len=np.inf, return_list=True, n_jobs=1):
+                  sorting='2-norm', scl=1, verbose=1,
+                  max_len=np.inf, return_list=False, n_jobs=1):
         
         super().__init__()
         self.tol = tol
